
## Concept

### Explanation

Importing StyleSheet from react-native, it allows you to use a syntax that looks similar to css stylesheet, but is in fact nested objects that you're passing into StyleSheet.create, which will return styles.className that you can use in style attributes

- importing StyleSheet:
```
import { StyleSheet } from 'react-native';
```
- Inline style given a style.className:
```
 <View style={styles.modalView}>
```
- StyleSheet declaration that looks much like CSS stylesheet and that fills the style nested object for usage in style attributes:
```
const styles = StyleSheet.create({  
  modalView: {
    elevation: 5,
    backgroundColor: 'white',
    padding: 20,
    borderRadius: 10,
    alignItems: 'center',
  },
  modalOverlay: {
    flex: 1,
    backgroundColor: 'rgba(0, 0, 0, 0.7)', // Dark shadow background
    justifyContent: 'center',
    alignItems: 'center',
  },
  button: {
    borderRadius: 20,
    padding: 10,
    elevation: 2,
  },
  buttonSecondary: {
    borderRadius: 20,
    padding: 10,
    elevation: 2,
    backgroundColor: 'white',
    borderWidth: 1,
    borderColor: '#000',
    marginBottom: 8,
  },
  buttonOpen: {
    backgroundColor: '#F194FF',
  },
  buttonClose: {
    backgroundColor: '#2196F3',
  },
});

```

### Why Use `StyleSheet.create()`?

1. **Performance & Optimization**
    - Styles are frozen and assigned IDs → faster rendering.    
    - Internally optimized for native performance.  
2. **Static Validation**
    - Catches typos (e.g., `backgrounColor`) early.
    - Validates styles for supported platforms.
3. **Code Consistency**
    - Encourages centralized, DRY style definitions.
    - Easier to maintain than scattered inline styles.

Note: If you're ever building truly **dynamic styles** (like based on props or screen dimensions), you'll often still use **inline styles or computed objects**, but for all **static styles**, `StyleSheet.create()` is preferred.

---

## 📱 Practice: React Native Modal Popup Tutorial

### ✅ What You’ll Build:

A button that opens a **modal overlay** with a **dark background** and styled **buttons** inside the modal.

---

### 🛠 Prerequisites:

- React Native environment set up (e.g. using [Expo](https://expo.dev/) or CLI)
    
- Basic knowledge of components and hooks (`useState`)
    

---

### 1. **Setup Your Project**

If you’re using Expo:

```bash
npx create-expo-app ModalExample
cd ModalExample
npx expo start
```

---

### 2. **Create the Modal Component**

Inside `App.js`:

```jsx
import React, { useState } from 'react';
import { Modal, View, Text, Pressable, StyleSheet } from 'react-native';

export default function App() {
  const [modalVisible, setModalVisible] = useState(false);

  return (
    <View style={{ flex: 1, justifyContent: 'center', alignItems: 'center' }}>
      {/* Button to Open Modal */}
      <Pressable
        style={[styles.button, styles.buttonOpen]}
        onPress={() => setModalVisible(true)}
      >
        <Text style={{ color: 'white' }}>Open Modal</Text>
      </Pressable>

      {/* Modal Component */}
      <Modal
        transparent={true}
        animationType="fade"
        visible={modalVisible}
        onRequestClose={() => setModalVisible(false)}
      >
        <View style={styles.modalOverlay}>
          <View style={styles.modalView}>
            <Text style={{ marginBottom: 16, textAlign: 'center' }}>
              Hello! This is your modal content.
            </Text>

            {/* Secondary Button (styled as outlined) */}
            <Pressable
              style={styles.buttonSecondary}
              onPress={() => alert('Secondary button clicked')}
            >
              <Text>Secondary Action</Text>
            </Pressable>

            {/* Close Button */}
            <Pressable
              style={[styles.button, styles.buttonClose]}
              onPress={() => setModalVisible(false)}
            >
              <Text style={{ color: 'white' }}>Close Modal</Text>
            </Pressable>
          </View>
        </View>
      </Modal>
    </View>
  );
}
```

---

### 3. **Add the StyleSheet**

Below your component or in a separate file if you prefer:

```jsx
const styles = StyleSheet.create({  
  modalView: {
    elevation: 5,
    backgroundColor: 'white',
    padding: 20,
    borderRadius: 10,
    alignItems: 'center',
  },
  modalOverlay: {
    flex: 1,
    backgroundColor: 'rgba(0, 0, 0, 0.7)', // Dark shadow background
    justifyContent: 'center',
    alignItems: 'center',
  },
  button: {
    borderRadius: 20,
    padding: 10,
    elevation: 2,
  },
  buttonSecondary: {
    borderRadius: 20,
    padding: 10,
    elevation: 2,
    backgroundColor: 'white',
    borderWidth: 1,
    borderColor: '#000',
    marginBottom: 8,
  },
  buttonOpen: {
    backgroundColor: '#F194FF',
  },
  buttonClose: {
    backgroundColor: '#2196F3',
  },
});
```

> 📝 **Note:** `border: '1px solid #000'` isn't valid in React Native. Use `borderWidth` and `borderColor` as shown above.

---

### 🎉 Result

You now have:

- A centered modal with a semi-transparent dark overlay
    
- Two buttons: one to close the modal, one as a secondary action
    
- Smooth animation and shadow (`elevation`) support on Android
    

---

Want to add custom transitions or icons next? I can walk you through that too!